"use strict";

var _react = _interopRequireDefault(require("react"));

var _testUtilities = require("../../test-utilities");

var _VisuallyHidden = require("../VisuallyHidden");

var _Form = require("./Form");

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { "default": obj }; }

describe('<Form />', function () {
  it('defaults to an empty action, POST method, and no validation', function () {
    var form = (0, _testUtilities.mountWithContext)( /*#__PURE__*/_react["default"].createElement(_Form.Form, {
      onSubmit: noop
    }));
    expect(form).toContainReactComponent('form', {
      action: '',
      method: 'POST',
      noValidate: true
    });
  });
  it('calls onSubmit when the form is submitted', function () {
    var onSubmit = jest.fn();
    var form = (0, _testUtilities.mountWithContext)( /*#__PURE__*/_react["default"].createElement(_Form.Form, {
      onSubmit: onSubmit
    }));
    form.find('form').trigger('onSubmit', createSubmitEvent());
    expect(onSubmit).toHaveBeenCalled();
  });
  it('prevents default when the form is submitted', function () {
    var event = createSubmitEvent();
    var form = (0, _testUtilities.mountWithContext)( /*#__PURE__*/_react["default"].createElement(_Form.Form, {
      onSubmit: noop
    }));
    form.find('form').trigger('onSubmit', event);
    expect(event.preventDefault).toHaveBeenCalled();
  });
  describe('implicitSubmit', function () {
    it('renders a visually hidden submit with the submit label by default', function () {
      var expectedLabel = 'Submit';
      var form = (0, _testUtilities.mountWithContext)( /*#__PURE__*/_react["default"].createElement(_Form.Form, {
        onSubmit: noop
      }), {
        translate: function translate(key) {
          return key === 'submit' ? expectedLabel : 'abc';
        }
      });
      expect(form.find(_VisuallyHidden.VisuallyHidden)).toContainReactComponent('button', {
        type: 'submit',
        children: expectedLabel,
        tabIndex: -1,
        'aria-hidden': true
      });
    });
    it('renders a visually hidden submit with a custom label', function () {
      var expectedLabel = 'Complete purchase';
      var form = (0, _testUtilities.mountWithContext)( /*#__PURE__*/_react["default"].createElement(_Form.Form, {
        onSubmit: noop,
        implicitSubmit: expectedLabel
      }));
      expect(form.find(_VisuallyHidden.VisuallyHidden)).toContainReactComponent('button', {
        type: 'submit',
        children: expectedLabel
      });
    });
    it('does not render a visually hidden submit when false', function () {
      var form = (0, _testUtilities.mountWithContext)( /*#__PURE__*/_react["default"].createElement(_Form.Form, {
        onSubmit: noop,
        implicitSubmit: false
      }));
      expect(form).not.toContainReactComponent(_VisuallyHidden.VisuallyHidden);
      expect(form).not.toContainReactComponent('button', {
        type: 'submit'
      });
    });
    it('disables the submit when disabled is true', function () {
      var form = (0, _testUtilities.mountWithContext)( /*#__PURE__*/_react["default"].createElement(_Form.Form, {
        onSubmit: noop,
        disabled: true
      }));
      expect(form.find(_VisuallyHidden.VisuallyHidden)).toContainReactComponent('button', {
        type: 'submit',
        disabled: true
      });
    });
  });
});

function createSubmitEvent() {
  return {
    preventDefault: jest.fn()
  };
}

function noop() {}