"use strict";

var _react = _interopRequireDefault(require("react"));

var _dom = require("@quilted/react-testing/dom");

var _Popper = require("./Popper");

var _context = require("./context");

var _offsets = require("./utilities/offsets");

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { "default": obj }; }

var defaultProps = {
  activator: null
};
describe('<Popper />', function () {
  it('render its children', function () {
    var content = 'content';
    var popper = (0, _dom.mount)( /*#__PURE__*/_react["default"].createElement(_Popper.Popper, defaultProps, content));
    expect(popper).toContainReactText('content');
  });
  it('wraps children with PopperContext', function () {
    var content = 'content';
    var placement = 'bottom';
    var popper = (0, _dom.mount)( /*#__PURE__*/_react["default"].createElement(_Popper.Popper, Object.assign({
      placement: placement
    }, defaultProps), content));
    expect(popper).toProvideReactContext(_context.PopperContext, {
      offsets: {
        x: 0,
        y: 0
      },
      clipping: {},
      placement: placement,
      popperRect: {
        bottom: 0,
        height: 0,
        left: 0,
        right: 0,
        top: 0,
        width: 0
      },
      referenceRect: null
    });
  });
  describe('computeOffsets', function () {
    it('computes default offsets when reference and popper rect are null', function () {
      var _computeOffsets = (0, _offsets.computeOffsets)('top', null, null),
          offsets = _computeOffsets.offsets;

      expect(offsets).toStrictEqual({
        x: 0,
        y: 0
      });
    });
    it('computes top center offsets with reference larger than popper', function () {
      var referenceWidth = 100;
      var referenceHeight = 40;
      var popperWidth = 40;
      var popperHeight = 20;
      var referenceRect = {
        bottom: 100 + referenceHeight,
        height: referenceHeight,
        top: 100,
        left: 100,
        width: referenceWidth,
        right: 100 + referenceWidth
      };
      var popperRect = {
        bottom: popperHeight,
        height: popperHeight,
        right: popperWidth,
        width: popperWidth
      };

      var _computeOffsets2 = (0, _offsets.computeOffsets)('top', popperRect, referenceRect),
          offsets = _computeOffsets2.offsets;

      expect(offsets).toStrictEqual({
        x: 130,
        y: 80
      });
      expect(offsets.x).toBeGreaterThan(referenceRect.left);
      expect(offsets.y).toBeLessThan(referenceRect.top);
    });
    it('computes bottom center offsets with reference larger than popper', function () {
      var referenceWidth = 100;
      var referenceHeight = 40;
      var popperWidth = 40;
      var popperHeight = 20;
      var referenceRect = {
        bottom: 100 + referenceHeight,
        height: referenceHeight,
        top: 100,
        left: 100,
        width: referenceWidth,
        right: 100 + referenceWidth
      };
      var popperRect = {
        bottom: popperHeight,
        height: popperHeight,
        right: popperWidth,
        width: popperWidth
      };

      var _computeOffsets3 = (0, _offsets.computeOffsets)('bottom', popperRect, referenceRect),
          offsets = _computeOffsets3.offsets;

      expect(offsets).toStrictEqual({
        x: 130,
        y: 140
      });
      expect(offsets.x).toBeGreaterThan(referenceRect.left);
      expect(offsets.y).toBeGreaterThan(referenceRect.top);
    });
    it('computes top center offsets with reference smaller than popper', function () {
      var referenceWidth = 40;
      var referenceHeight = 20;
      var popperWidth = 100;
      var popperHeight = 40;
      var referenceRect = {
        bottom: 100 + referenceHeight,
        height: referenceHeight,
        top: 100,
        left: 100,
        width: referenceWidth,
        right: 100 + referenceWidth
      };
      var popperRect = {
        bottom: popperHeight,
        height: popperHeight,
        right: popperWidth,
        width: popperWidth
      };

      var _computeOffsets4 = (0, _offsets.computeOffsets)('top', popperRect, referenceRect),
          offsets = _computeOffsets4.offsets;

      expect(offsets).toStrictEqual({
        x: 70,
        y: 60
      });
      expect(offsets.x).toBeLessThan(referenceRect.left);
      expect(offsets.y).toBeLessThan(referenceRect.top);
    });
    it('computes bottom center offsets with reference smaller than popper', function () {
      var referenceWidth = 40;
      var referenceHeight = 20;
      var popperWidth = 100;
      var popperHeight = 40;
      var referenceRect = {
        bottom: 100 + referenceHeight,
        height: referenceHeight,
        top: 100,
        left: 100,
        width: referenceWidth,
        right: 100 + referenceWidth
      };
      var popperRect = {
        bottom: popperHeight,
        height: popperHeight,
        right: popperWidth,
        width: popperWidth
      };

      var _computeOffsets5 = (0, _offsets.computeOffsets)('bottom', popperRect, referenceRect),
          offsets = _computeOffsets5.offsets;

      expect(offsets).toStrictEqual({
        x: 70,
        y: 120
      });
      expect(offsets.x).toBeLessThan(referenceRect.left);
      expect(offsets.y).toBeGreaterThan(referenceRect.top);
    });
    it('computes offsets with reference larger than popper and sameWidth option', function () {
      var referenceWidth = 100;
      var referenceHeight = 40;
      var popperWidth = 40;
      var popperHeight = 20;
      var referenceRect = {
        bottom: 100 + referenceHeight,
        height: referenceHeight,
        top: 100,
        left: 100,
        width: referenceWidth,
        right: 100 + referenceWidth
      };
      var popperRect = {
        bottom: popperHeight,
        height: popperHeight,
        right: popperWidth,
        width: popperWidth
      };

      var _computeOffsets6 = (0, _offsets.computeOffsets)('top', popperRect, referenceRect, {
        sameWidth: true
      }),
          offsets = _computeOffsets6.offsets;

      expect(offsets).toStrictEqual({
        x: 100,
        y: 80
      });
      expect(offsets.x).toBe(referenceRect.left);
      expect(offsets.y).toBeLessThan(referenceRect.top);
    });
  });
});