function _slicedToArray(arr, i) { return _arrayWithHoles(arr) || _iterableToArrayLimit(arr, i) || _unsupportedIterableToArray(arr, i) || _nonIterableRest(); }

function _nonIterableRest() { throw new TypeError("Invalid attempt to destructure non-iterable instance.\nIn order to be iterable, non-array objects must have a [Symbol.iterator]() method."); }

function _unsupportedIterableToArray(o, minLen) { if (!o) return; if (typeof o === "string") return _arrayLikeToArray(o, minLen); var n = Object.prototype.toString.call(o).slice(8, -1); if (n === "Object" && o.constructor) n = o.constructor.name; if (n === "Map" || n === "Set") return Array.from(o); if (n === "Arguments" || /^(?:Ui|I)nt(?:8|16|32)(?:Clamped)?Array$/.test(n)) return _arrayLikeToArray(o, minLen); }

function _arrayLikeToArray(arr, len) { if (len == null || len > arr.length) len = arr.length; for (var i = 0, arr2 = new Array(len); i < len; i++) { arr2[i] = arr[i]; } return arr2; }

function _iterableToArrayLimit(arr, i) { if (typeof Symbol === "undefined" || !(Symbol.iterator in Object(arr))) return; var _arr = []; var _n = true; var _d = false; var _e = undefined; try { for (var _i = arr[Symbol.iterator](), _s; !(_n = (_s = _i.next()).done); _n = true) { _arr.push(_s.value); if (i && _arr.length === i) break; } } catch (err) { _d = true; _e = err; } finally { try { if (!_n && _i["return"] != null) _i["return"](); } finally { if (_d) throw _e; } } return _arr; }

function _arrayWithHoles(arr) { if (Array.isArray(arr)) return arr; }

import React from 'react';
import faker from 'faker';
import { mountWithContext } from '../../test-utilities';
import { Icon } from '../Icon';
import { Text } from '../Text';
import { Link } from '../Link';
import { createTheme } from '../Theme';
import { Breadcrumbs, Marker } from './Breadcrumbs';
describe('<Breadcrumbs />', function () {
  it('does not render a separator after the final breadcrumb', function () {
    var baseBreadcrumbs = [{
      id: faker.random.uuid(),
      to: faker.internet.url(),
      content: faker.random.word()
    }, {
      id: faker.random.uuid(),
      to: faker.internet.url(),
      content: faker.random.word()
    }];
    var breadcrumbs = mountWithContext( /*#__PURE__*/React.createElement(Breadcrumbs, {
      breadcrumbs: baseBreadcrumbs
    }));

    var _breadcrumbs$findAll = breadcrumbs.findAll('li'),
        _breadcrumbs$findAll2 = _slicedToArray(_breadcrumbs$findAll, 2),
        firstBreadcrumb = _breadcrumbs$findAll2[0],
        finalBreadcrumb = _breadcrumbs$findAll2[1];

    expect(firstBreadcrumb).toContainReactComponent(Icon, {
      source: 'chevronRight'
    });
    expect(finalBreadcrumb).not.toContainReactComponent(Icon, {
      source: 'chevronRight'
    });
  });
  it('renders a Link for breadcrumbs that are neither active nor disabled', function () {
    var to = faker.internet.url();
    var content = faker.random.word();
    var withDefaultBreadcrumb = [{
      id: faker.random.uuid(),
      to: to,
      content: content
    }];
    var breadcrumbs = mountWithContext( /*#__PURE__*/React.createElement(Breadcrumbs, {
      breadcrumbs: withDefaultBreadcrumb
    }));

    var _breadcrumbs$findAll3 = breadcrumbs.findAll('li'),
        _breadcrumbs$findAll4 = _slicedToArray(_breadcrumbs$findAll3, 1),
        defaultBreadcrumb = _breadcrumbs$findAll4[0];

    expect(defaultBreadcrumb).toContainReactComponent(Link, {
      to: to
    });
    expect(defaultBreadcrumb).toContainReactText(content);
  });
  it('does not render a Link and sets the aria-current for active breadcrumb', function () {
    var id = faker.random.uuid();
    var content = faker.random.word();
    var withActiveBreadcrumb = [{
      id: id,
      to: faker.internet.url(),
      content: content
    }];
    var wrapper = mountWithContext( /*#__PURE__*/React.createElement(Breadcrumbs, {
      active: id,
      breadcrumbs: withActiveBreadcrumb
    }));

    var _wrapper$findAll = wrapper.findAll('li'),
        _wrapper$findAll2 = _slicedToArray(_wrapper$findAll, 1),
        activeBreadcrumb = _wrapper$findAll2[0];

    expect(activeBreadcrumb).toContainReactComponent(Text, {
      children: [null, content],
      emphasized: true
    });
    expect(activeBreadcrumb).toHaveReactProps({
      'aria-current': 'step'
    });
  });
  it('does not render Link if breadcrumb is disabled', function () {
    var content = faker.random.word();
    var withDisabledBreadcrumb = [{
      id: faker.random.uuid(),
      to: faker.internet.url(),
      content: content,
      disabled: true
    }];
    var wrapper = mountWithContext( /*#__PURE__*/React.createElement(Breadcrumbs, {
      breadcrumbs: withDisabledBreadcrumb
    }));

    var _wrapper$findAll3 = wrapper.findAll('li'),
        _wrapper$findAll4 = _slicedToArray(_wrapper$findAll3, 1),
        disabledBreadcrumb = _wrapper$findAll4[0];

    expect(disabledBreadcrumb).toContainReactComponent(Text, {
      children: [null, content]
    });
  });
  it('emphasizes active breadcrumbs', function () {
    var content = faker.random.word();
    var activeId = faker.random.uuid();
    var withActiveBreadcrumb = [{
      id: activeId,
      to: faker.internet.url(),
      content: content
    }];
    var wrapper = mountWithContext( /*#__PURE__*/React.createElement(Breadcrumbs, {
      active: activeId,
      breadcrumbs: withActiveBreadcrumb
    }));

    var _wrapper$findAll5 = wrapper.findAll('li'),
        _wrapper$findAll6 = _slicedToArray(_wrapper$findAll5, 1),
        activeBreadcrumb = _wrapper$findAll6[0];

    expect(activeBreadcrumb).toContainReactComponent(Text, {
      emphasized: true,
      children: [null, content]
    });
  });
  it('subdues disabled breadcrumbs', function () {
    var content = faker.random.word();
    var withDisabledBreadcrumb = [{
      id: faker.random.uuid(),
      to: faker.internet.url(),
      content: content,
      disabled: true
    }];
    var wrapper = mountWithContext( /*#__PURE__*/React.createElement(Breadcrumbs, {
      breadcrumbs: withDisabledBreadcrumb
    }));

    var _wrapper$findAll7 = wrapper.findAll('li'),
        _wrapper$findAll8 = _slicedToArray(_wrapper$findAll7, 1),
        disabledBreadcrumb = _wrapper$findAll8[0];

    expect(disabledBreadcrumb).toContainReactComponent(Text, {
      subdued: true,
      children: [null, content]
    });
  });
  it('numberStyle theme renders a marker', function () {
    var content = faker.random.word();
    var breadcrumbs = [{
      id: faker.random.uuid(),
      to: faker.internet.url(),
      content: content
    }, {
      id: faker.random.uuid(),
      to: faker.internet.url(),
      content: content
    }];
    var wrapper = mountWithContext( /*#__PURE__*/React.createElement(Breadcrumbs, {
      breadcrumbs: breadcrumbs
    }), {
      theme: createTheme({
        buyerJourney: {
          numberStyle: 'decimalLeadingZero'
        }
      })
    });
    wrapper.findAll('li').forEach(function (breadcrumb, index) {
      expect(breadcrumb).toContainReactComponent(Marker, {
        children: "0".concat(index + 1)
      });
    });
  });
});