"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.Checkbox = Checkbox;
exports.CheckboxControl = CheckboxControl;

var _react = _interopRequireDefault(require("react"));

var _cssUtilities = require("@shopify/css-utilities");

var _Icon = require("../Icon");

var _VisuallyHidden = require("../VisuallyHidden");

var _HiddenForAccessibility = require("../HiddenForAccessibility");

var _InlineError = require("../InlineError");

var _Theme = require("../Theme");

var _id = require("../../utilities/id");

var _errors = require("../../utilities/errors");

var _Checkbox = _interopRequireDefault(require("./Checkbox.css"));

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

const createId = (0, _id.createIdCreator)('Checkbox');

function Checkbox({
  id: explicitId,
  accessibilityLabel,
  error,
  disabled,
  children,
  ...rest
}) {
  const id = (0, _id.useId)(explicitId, createId);
  const errorMarkup = error ? /*#__PURE__*/_react.default.createElement("div", {
    className: _Checkbox.default.Error
  }, /*#__PURE__*/_react.default.createElement(_InlineError.InlineError, {
    controlID: id
  }, error)) : null;
  const labelClassName = (0, _cssUtilities.classNames)(_Checkbox.default.Label, disabled && _Checkbox.default['Label-isDisabled']);
  return /*#__PURE__*/_react.default.createElement("div", {
    className: (0, _cssUtilities.classNames)(_Checkbox.default.Wrapper, Boolean(error) && _Checkbox.default.hasError)
  }, /*#__PURE__*/_react.default.createElement(CheckboxControl, Object.assign({
    id: id,
    name: name,
    error: Boolean(error),
    disabled: disabled
  }, rest)), /*#__PURE__*/_react.default.createElement("label", {
    htmlFor: id,
    className: labelClassName
  }, accessibilityLabel ? /*#__PURE__*/_react.default.createElement(_react.default.Fragment, null, /*#__PURE__*/_react.default.createElement(_VisuallyHidden.VisuallyHidden, null, accessibilityLabel), /*#__PURE__*/_react.default.createElement(_HiddenForAccessibility.HiddenForAccessibility, null, children)) : children), errorMarkup);
}

function CheckboxControl({
  id,
  name,
  value = false,
  checked = value,
  disabled,
  error = false,
  onChange
}) {
  const {
    checkbox: {
      background = 'surfaceTertiary',
      borderColor = 'base'
    }
  } = (0, _Theme.useThemeConfiguration)();
  const className = (0, _cssUtilities.classNames)(_Checkbox.default.Input, error && _Checkbox.default['Input-hasError'], disabled && _Checkbox.default['Input-isDisabled'], _Checkbox.default[(0, _cssUtilities.variationName)('Input-background', background)], _Checkbox.default[(0, _cssUtilities.variationName)('Input-borderColor', borderColor)]);
  return /*#__PURE__*/_react.default.createElement("div", {
    className: _Checkbox.default.Checkbox
  }, /*#__PURE__*/_react.default.createElement("input", {
    type: "checkbox",
    id: id,
    name: name,
    checked: checked,
    disabled: disabled,
    onChange: ({
      currentTarget
    }) => {
      onChange === null || onChange === void 0 ? void 0 : onChange(currentTarget.checked);
    },
    className: className,
    "aria-describedby": error ? (0, _errors.errorId)(id) : undefined,
    "aria-invalid": error
  }), /*#__PURE__*/_react.default.createElement("div", {
    className: _Checkbox.default.Icon
  }, /*#__PURE__*/_react.default.createElement(_Icon.Icon, {
    source: "checkmark",
    size: "small"
  })));
}