"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.Shell = Shell;
exports.ShellHeader = ShellHeader;
exports.ShellSubheader = ShellSubheader;
exports.ShellHeading = ShellHeading;
exports.ShellSection = ShellSection;
exports.ShellSectionContent = ShellSectionContent;
exports.ShellFooter = ShellFooter;
exports.ShellDisclosure = ShellDisclosure;

var _react = _interopRequireWildcard(require("react"));

var _cssUtilities = require("@shopify/css-utilities");

var _InlineStack = require("../InlineStack");

var _HeadingGroup = require("../HeadingGroup");

var _Icon = require("../Icon");

var _Text = require("../Text");

var _legacy = require("../../utilities/legacy");

var _transition = require("../../utilities/transition");

var _Shell = _interopRequireDefault(require("./Shell.css"));

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

function _getRequireWildcardCache() { if (typeof WeakMap !== "function") return null; var cache = new WeakMap(); _getRequireWildcardCache = function () { return cache; }; return cache; }

function _interopRequireWildcard(obj) { if (obj && obj.__esModule) { return obj; } if (obj === null || typeof obj !== "object" && typeof obj !== "function") { return { default: obj }; } var cache = _getRequireWildcardCache(); if (cache && cache.has(obj)) { return cache.get(obj); } var newObj = {}; var hasPropertyDescriptor = Object.defineProperty && Object.getOwnPropertyDescriptor; for (var key in obj) { if (Object.prototype.hasOwnProperty.call(obj, key)) { var desc = hasPropertyDescriptor ? Object.getOwnPropertyDescriptor(obj, key) : null; if (desc && (desc.get || desc.set)) { Object.defineProperty(newObj, key, desc); } else { newObj[key] = obj[key]; } } } newObj.default = obj; if (cache) { cache.set(obj, newObj); } return newObj; }

function Shell({
  children,
  headerPosition,
  subheaderPosition,
  footerPosition,
  subheaderHidden
}) {
  return /*#__PURE__*/_react.default.createElement("div", {
    className: (0, _cssUtilities.classNames)(_Shell.default.Shell, headerPosition && _Shell.default[(0, _cssUtilities.variationName)('headerPosition', headerPosition)], subheaderPosition && _Shell.default[(0, _cssUtilities.variationName)('subheaderPosition', subheaderPosition)], footerPosition && _Shell.default[(0, _cssUtilities.variationName)('footerPosition', footerPosition)], subheaderHidden && _Shell.default.subheaderHidden)
  }, children);
}

function ShellHeader({
  children,
  alignment,
  blockPadding,
  background
}) {
  const style = background ? {
    backgroundImage: `url(${JSON.stringify(background)})`
  } : undefined;
  return /*#__PURE__*/_react.default.createElement(_HeadingGroup.HeadingGroup, null, /*#__PURE__*/_react.default.createElement("header", {
    role: "banner",
    style: style,
    className: (0, _cssUtilities.classNames)(_Shell.default.Header, _Shell.default[(0, _cssUtilities.variationName)('Header-alignment', alignment)], _Shell.default[(0, _cssUtilities.variationName)('Header-blockPadding', blockPadding)])
  }, /*#__PURE__*/_react.default.createElement("div", {
    className: _Shell.default.HeaderInner
  }, children)));
}

function ShellSubheader({
  children,
  alignment
}) {
  return /*#__PURE__*/_react.default.createElement("div", {
    className: (0, _cssUtilities.classNames)(_Shell.default.Subheader, _Shell.default[(0, _cssUtilities.variationName)('Subheader-alignment', alignment)])
  }, /*#__PURE__*/_react.default.createElement("div", {
    className: _Shell.default.SubheaderInner
  }, children));
}

function ShellHeading({
  to,
  logo,
  children
}) {
  const content = (logo === null || logo === void 0 ? void 0 : logo.source) ? /*#__PURE__*/_react.default.createElement("img", {
    src: logo.source,
    alt: children // TODO: convert to rems
    ,
    style: logo.maxWidth ? {
      maxWidth: logo.maxWidth
    } : undefined,
    className: _Shell.default.Logo
  }) : children;
  return to ? /*#__PURE__*/_react.default.createElement("a", {
    className: _Shell.default.Heading,
    href: to
  }, content) : /*#__PURE__*/_react.default.createElement("span", {
    className: _Shell.default.Heading
  }, content);
}

function ShellSection({
  bordered,
  background,
  inlineSize,
  blockSize,
  children,
  secondary
}) {
  const Element = secondary ? 'aside' : 'div';
  return /*#__PURE__*/_react.default.createElement(_HeadingGroup.HeadingGroup, null, /*#__PURE__*/_react.default.createElement(Element, {
    className: (0, _cssUtilities.classNames)(_Shell.default.Section, bordered && _Shell.default['Section-bordered'], background && backgroundToLegacyClassName(background), background && _Shell.default[(0, _cssUtilities.variationName)('Section-background', background)], inlineSize && _Shell.default[(0, _cssUtilities.variationName)('Section-inlineSize', inlineSize)], blockSize && _Shell.default[(0, _cssUtilities.variationName)('Section-blockSize', blockSize)], secondary && _Shell.default['Section-secondary'])
  }, /*#__PURE__*/_react.default.createElement("div", {
    className: _Shell.default.SectionInner
  }, children)));
}

function ShellSectionContent({
  children
}) {
  return /*#__PURE__*/_react.default.createElement("div", {
    className: _Shell.default.SectionContent
  }, /*#__PURE__*/_react.default.createElement("div", {
    className: _Shell.default.SectionContentInner
  }, children));
}

function ShellFooter({
  children
}) {
  return /*#__PURE__*/_react.default.createElement(_HeadingGroup.HeadingGroup, null, /*#__PURE__*/_react.default.createElement("footer", {
    role: "contentinfo",
    className: _Shell.default.Footer
  }, /*#__PURE__*/_react.default.createElement("div", {
    className: _Shell.default.FooterInner
  }, children)));
}

// TODO: a11y
function ShellDisclosure({
  children,
  detail,
  labels,
  icon,
  bordered,
  background
}) {
  const [open, setOpen] = (0, _react.useState)(false);
  const disclosureRef = (0, _react.useRef)(null);
  const transition = (0, _transition.useTransition)(open, 'slow');
  const transitionStyles = {
    enter: () => ({
      height: 0
    }),
    entering: () => {
      var _disclosureRef$curren;

      return {
        height: disclosureRef === null || disclosureRef === void 0 ? void 0 : (_disclosureRef$curren = disclosureRef.current) === null || _disclosureRef$curren === void 0 ? void 0 : _disclosureRef$curren.clientHeight
      };
    },
    entered: () => ({
      height: 'auto'
    }),
    exit: () => {
      var _disclosureRef$curren2;

      return {
        height: disclosureRef === null || disclosureRef === void 0 ? void 0 : (_disclosureRef$curren2 = disclosureRef.current) === null || _disclosureRef$curren2 === void 0 ? void 0 : _disclosureRef$curren2.clientHeight
      };
    },
    exiting: () => ({
      height: 0
    })
  };
  const {
    text,
    icon: disclosureIcon
  } = open ? {
    text: labels.closed,
    icon: /*#__PURE__*/_react.default.createElement(_Icon.Icon, {
      source: "chevronUp",
      size: "small",
      color: "interactive"
    })
  } : {
    text: labels.open,
    icon: /*#__PURE__*/_react.default.createElement(_Icon.Icon, {
      source: "chevronDown",
      size: "small",
      color: "interactive"
    })
  };
  const contentId = 'disclosure_content';
  return /*#__PURE__*/_react.default.createElement("aside", {
    className: (0, _cssUtilities.classNames)(_Shell.default.Disclosure, bordered && _Shell.default['Disclosure-bordered'], background && backgroundToLegacyClassName(background), background && _Shell.default[(0, _cssUtilities.variationName)('Disclosure-background', background)])
  }, /*#__PURE__*/_react.default.createElement("button", {
    type: "button",
    className: (0, _cssUtilities.classNames)(_Shell.default.DisclosureButton, _legacy.utilityDefaultBorderColor),
    onClick: () => setOpen(open => !open),
    "aria-pressed": open,
    "aria-controls": contentId,
    "aria-expanded": open
  }, /*#__PURE__*/_react.default.createElement("span", {
    className: _Shell.default.DisclosureLayout
  }, /*#__PURE__*/_react.default.createElement(_InlineStack.InlineStack, {
    spacing: "tight",
    alignment: "center"
  }, /*#__PURE__*/_react.default.createElement(_Icon.Icon, {
    source: icon,
    size: "large",
    color: "interactive"
  }), /*#__PURE__*/_react.default.createElement(_Text.Text, null, text), disclosureIcon), detail)), transition !== 'exited' && /*#__PURE__*/_react.default.createElement("div", {
    className: (0, _cssUtilities.classNames)(_Shell.default.DisclosureContent, _legacy.utilityDefaultBorderColor),
    style: { ...transitionStyles[transition]()
    },
    id: contentId
  }, /*#__PURE__*/_react.default.createElement("div", {
    className: _Shell.default.DisclosureContentInner,
    ref: disclosureRef
  }, children)));
}

function backgroundToLegacyClassName(background) {
  switch (background) {
    case 'surfacePrimary':
      return _legacy.colorSurfacePrimary;

    case 'surfaceSecondary':
      return _legacy.colorSurfaceSecondary;

    case 'surfaceTertiary':
      return _legacy.colorSurfaceTertiary;
  }
}