"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.CustomPropertiesFallback = void 0;

var _react = _interopRequireWildcard(require("react"));

var _hooks = require("../../hooks");

var legacyStyles = _interopRequireWildcard(require("../../../../utilities/legacy"));

function _getRequireWildcardCache() { if (typeof WeakMap !== "function") return null; var cache = new WeakMap(); _getRequireWildcardCache = function () { return cache; }; return cache; }

function _interopRequireWildcard(obj) { if (obj && obj.__esModule) { return obj; } if (obj === null || typeof obj !== "object" && typeof obj !== "function") { return { default: obj }; } var cache = _getRequireWildcardCache(); if (cache && cache.has(obj)) { return cache.get(obj); } var newObj = {}; var hasPropertyDescriptor = Object.defineProperty && Object.getOwnPropertyDescriptor; for (var key in obj) { if (Object.prototype.hasOwnProperty.call(obj, key)) { var desc = hasPropertyDescriptor ? Object.getOwnPropertyDescriptor(obj, key) : null; if (desc && (desc.get || desc.set)) { Object.defineProperty(newObj, key, desc); } else { newObj[key] = obj[key]; } } } newObj.default = obj; if (cache) { cache.set(obj, newObj); } return newObj; }

const CustomPropertiesFallback = /*#__PURE__*/(0, _react.memo)(function CustomPropertiesFallback() {
  const theme = (0, _hooks.useTheme)();
  const [customProperties, setCustomProperties] = (0, _react.useState)(theme.customProperties);
  (0, _react.useEffect)(() => {
    return theme.on('preview', customProperties => {
      setCustomProperties(existing => ({ ...existing,
        ...customProperties
      }));
    });
  }, [theme]);
  const css = (0, _react.useMemo)(() => toCss(customProperties), [customProperties]);
  return /*#__PURE__*/_react.default.createElement("style", {
    dangerouslySetInnerHTML: {
      __html: css
    }
  });
});
exports.CustomPropertiesFallback = CustomPropertiesFallback;

function toCss(customProperties) {
  return cssFromObject({
    [`.${legacyStyles.button}`]: {
      color: customProperties.colorPrimaryText,
      background: customProperties.colorPrimary
    },
    [`.${legacyStyles.button}:hover`]: {
      background: customProperties.colorPrimaryHovered
    },
    [`.${legacyStyles.button}:active`]: {
      background: customProperties.colorPrimaryPressed
    },
    [`.${legacyStyles.colorCanvas}`]: {
      color: customProperties.colorCanvasText,
      'border-color': customProperties.colorCanvasBorder,
      'background-color': customProperties.colorCanvas
    },
    [`.${legacyStyles.colorCanvas} .${legacyStyles.utilityDefaultBorderColor}`]: {
      'border-color': customProperties.colorCanvasBorder
    },
    [`.${legacyStyles.colorCanvas} .${legacyStyles.utilityDefaultTextColorSubdued}`]: {
      color: customProperties.colorCanvasTextSubdued
    },
    [`.${legacyStyles.colorCanvas} .${legacyStyles.utilityDefaultTextColorEmphasized}`]: {
      color: customProperties.colorCanvasTextEmphasized
    },
    [`.${legacyStyles.colorSurfacePrimary}`]: {
      color: customProperties.colorSurfacePrimaryText,
      'border-color': customProperties.colorSurfacePrimaryBorder,
      'background-color': customProperties.colorSurfacePrimary
    },
    [`.${legacyStyles.colorSurfacePrimary} .${legacyStyles.utilityDefaultBorderColor}`]: {
      'border-color': customProperties.colorSurfacePrimaryBorder
    },
    [`.${legacyStyles.colorSurfacePrimary} .${legacyStyles.utilityDefaultTextColorSubdued}`]: {
      color: customProperties.colorSurfacePrimaryTextSubdued
    },
    [`.${legacyStyles.colorSurfacePrimary} .${legacyStyles.utilityDefaultTextColorEmphasized}`]: {
      color: customProperties.colorSurfacePrimaryTextEmphasized
    },
    [`.${legacyStyles.colorSurfaceSecondary}`]: {
      color: customProperties.colorSurfaceSecondaryText,
      'border-color': customProperties.colorSurfaceSecondaryBorder,
      'background-color': customProperties.colorSurfaceSecondary
    },
    [`.${legacyStyles.colorSurfaceSecondary} .${legacyStyles.utilityDefaultBorderColor}`]: {
      'border-color': customProperties.colorSurfaceSecondaryBorder
    },
    [`.${legacyStyles.colorSurfaceSecondary} .${legacyStyles.utilityDefaultTextColorSubdued}`]: {
      color: customProperties.colorSurfaceSecondaryTextSubdued
    },
    [`.${legacyStyles.colorSurfaceSecondary} .${legacyStyles.utilityDefaultTextColorEmphasized}`]: {
      color: customProperties.colorSurfaceSecondaryTextEmphasized
    },
    [`.${legacyStyles.colorSurfaceTertiary}`]: {
      color: customProperties.colorSurfaceTertiaryText,
      'border-color': customProperties.colorSurfaceTertiaryBorder,
      'background-color': customProperties.colorSurfaceTertiary
    },
    [`.${legacyStyles.colorSurfaceTertiary} .${legacyStyles.utilityDefaultBorderColor}`]: {
      'border-color': customProperties.colorSurfaceTertiaryBorder
    },
    [`.${legacyStyles.colorSurfaceTertiary} .${legacyStyles.utilityDefaultTextColorSubdued}`]: {
      color: customProperties.colorSurfaceTertiaryTextSubdued
    },
    [`.${legacyStyles.colorSurfaceTertiary} .${legacyStyles.utilityDefaultTextColorEmphasized}`]: {
      color: customProperties.colorSurfaceTertiaryTextEmphasized
    }
  });
}

function cssFromObject(cssObject) {
  const selectors = [];

  for (const selector of Object.keys(cssObject)) {
    const propertyValues = [];

    for (const property of Object.keys(cssObject[selector])) {
      const value = cssObject[selector][property];
      if (value) propertyValues.push(`${property}: ${value} !important;`);
    }

    if (propertyValues.length > 0) selectors.push(`${selector} {\n  ${propertyValues.join('\n  ')}\n}`);
  }

  return selectors.join('\n');
}