"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.themeWithKnobs = themeWithKnobs;

var _react = _interopRequireDefault(require("react"));

var _addonKnobs = require("@storybook/addon-knobs");

var _2 = require("..");

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

var Group;

(function (Group) {
  Group["TextFields"] = "Text fields";
  Group["Selects"] = "Selects";
  Group["Breadcrumbs"] = "Breadcrumbs";
  Group["Actions"] = "Actions";
  Group["HeadingsLevel1"] = "Headings level 1";
  Group["HeadingsLevel2"] = "Headings level 2";
  Group["HeadingsLevel3"] = "Headings level 3";
  Group["Checkbox"] = "Checkbox";
})(Group || (Group = {}));

var Label;

(function (Label) {
  Label["Border"] = "Border";
  Label["LabelPosition"] = "Label position";
})(Label || (Label = {}));

var Action;

(function (Action) {
  Action["Display"] = "Display";
})(Action || (Action = {}));

var Breadcrumb;

(function (Breadcrumb) {
  Breadcrumb["Gap"] = "Gap";
  Breadcrumb["ChevronIconSeparator"] = "Chevron icon separator";
  Breadcrumb["NumberStyle"] = "Number style";
})(Breadcrumb || (Breadcrumb = {}));

const SIMPLE_BORDER_RADIUS_OPTIONS = optionify(['none', 'base']);
const BORDER_OPTIONS = optionify(['full', 'blockEnd', 'none']);
const LABEL_POSITION_OPTIONS = optionify(['inside', 'outside']);
const ACTIONS_DISPLAY_OPTIONS = optionify(['inline', 'block']);
const BREADCRUMB_GAP_OPTIONS = optionify(['base', 'loose']);
const NUMBER_STYLE_OPTIONS = optionify(['none', 'decimal', 'decimalLeadingZero']);
const STYLE_OPTIONS = optionify(['style1', 'style2', 'style3', 'style4', 'style5', 'style6', 'style7', 'style8', 'style9']);
const SIZE_OPTIONS = optionify(['base', 'xsmall', 'small', 'medium', 'large', 'xlarge', 'xxlarge']);
const LETTER_CASE_OPTIONS = optionify(['none', 'title', 'upper', 'lower']);
const FONT_OPTIONS = optionify(['primary', 'secondary']);
const WEIGHT_OPTIONS = optionify(['base', 'bold']);
const LINE_SIZE_OPTIONS = optionify(['base', 'large']);
const KERNING_OPTIONS = optionify(['base', 'loose', 'xloose']);

function themeWithKnobs(...picks) {
  return storyFn => /*#__PURE__*/_react.default.createElement(ThemeWithKnobs, {
    pick: picks
  }, storyFn());
}

function ThemeWithKnobs({
  pick = [],
  children
}) {
  let textFieldsBorder;
  let selectBorder;
  let textFieldsLabelPosition;
  let selectLabelPosition;
  let actionsDisplay;
  let breadcrumbGap;
  let chevronIconSeparator = true;
  let numberStyle;
  let breadcrumbStyle;
  let headingLevel1Style;
  let headingLevel2Style;
  let headingLevel3Style;
  let checkboxBorderRadius;

  if (pick.includes('textFields')) {
    textFieldsBorder = (0, _addonKnobs.select)(Label.Border, BORDER_OPTIONS, textFieldsBorder, Group.TextFields);
    textFieldsLabelPosition = (0, _addonKnobs.select)(Label.LabelPosition, LABEL_POSITION_OPTIONS, textFieldsLabelPosition, Group.TextFields);
  }

  if (pick.includes('select')) {
    selectBorder = (0, _addonKnobs.select)(Label.Border, BORDER_OPTIONS, selectBorder, Group.Selects);
    selectLabelPosition = (0, _addonKnobs.select)(Label.LabelPosition, LABEL_POSITION_OPTIONS, selectLabelPosition, Group.Selects);
  }

  if (pick.includes('actions')) {
    actionsDisplay = (0, _addonKnobs.select)(Action.Display, ACTIONS_DISPLAY_OPTIONS, actionsDisplay, Group.Actions);
  }

  if (pick.includes('buyerJourney')) {
    breadcrumbGap = (0, _addonKnobs.select)(Breadcrumb.Gap, BREADCRUMB_GAP_OPTIONS, breadcrumbGap, Group.Breadcrumbs);
    chevronIconSeparator = (0, _addonKnobs.boolean)(Breadcrumb.ChevronIconSeparator, chevronIconSeparator, Group.Breadcrumbs);
    numberStyle = (0, _addonKnobs.select)(Breadcrumb.NumberStyle, NUMBER_STYLE_OPTIONS, numberStyle, Group.Breadcrumbs);
    breadcrumbStyle = (0, _addonKnobs.select)('Style', STYLE_OPTIONS, breadcrumbStyle, Group.Breadcrumbs);
  }

  if (pick.includes('checkbox')) {
    checkboxBorderRadius = (0, _addonKnobs.select)('Border radius', SIMPLE_BORDER_RADIUS_OPTIONS, checkboxBorderRadius, Group.Checkbox);
  }

  if (pick.includes('headingLevel1')) {
    headingLevel1Style = (0, _addonKnobs.select)('Style', STYLE_OPTIONS, headingLevel1Style, Group.HeadingsLevel1);
  }

  if (pick.includes('headingLevel2')) {
    headingLevel2Style = (0, _addonKnobs.select)('Style', STYLE_OPTIONS, headingLevel2Style, Group.HeadingsLevel2);
  }

  if (pick.includes('headingLevel3')) {
    headingLevel3Style = (0, _addonKnobs.select)('Style', STYLE_OPTIONS, headingLevel3Style, Group.HeadingsLevel3);
  }

  const typographyStyles = [...Array(9)].reduce((acc, _, index) => {
    const oneBasedIndex = index + 1;
    return { ...acc,
      [`typographyStyle${oneBasedIndex}`]: {
        size: (0, _addonKnobs.select)(`Style ${oneBasedIndex} size`, SIZE_OPTIONS, undefined, 'Styles'),
        letterCase: (0, _addonKnobs.select)(`Style ${oneBasedIndex} letter case`, LETTER_CASE_OPTIONS, undefined, 'Styles'),
        fonts: (0, _addonKnobs.select)(`Style ${oneBasedIndex} fonts`, FONT_OPTIONS, undefined, 'Styles'),
        weight: (0, _addonKnobs.select)(`Style ${oneBasedIndex} weight`, WEIGHT_OPTIONS, undefined, 'Styles'),
        lineSize: (0, _addonKnobs.select)(`Style ${oneBasedIndex} line size`, LINE_SIZE_OPTIONS, undefined, 'Styles'),
        kerning: (0, _addonKnobs.select)(`Style ${oneBasedIndex} kerning`, KERNING_OPTIONS, undefined, 'Styles')
      }
    };
  }, {});
  const theme = (0, _2.createTheme)({
    textFields: {
      border: textFieldsBorder,
      labelPosition: textFieldsLabelPosition
    },
    select: {
      border: selectBorder,
      labelPosition: selectLabelPosition
    },
    actions: {
      display: actionsDisplay
    },
    buyerJourney: {
      gap: breadcrumbGap,
      chevronIconSeparator,
      numberStyle,
      typographyStyle: breadcrumbStyle
    },
    headingLevel1: {
      typographyStyle: headingLevel1Style
    },
    headingLevel2: {
      typographyStyle: headingLevel2Style
    },
    headingLevel3: {
      typographyStyle: headingLevel3Style
    },
    ...typographyStyles,
    checkbox: {
      borderRadius: checkboxBorderRadius
    }
  });
  return /*#__PURE__*/_react.default.createElement(_2.Theme, {
    theme: theme
  }, children);
}

function optionify(array) {
  return array.reduce((acc, value) => ({ ...acc,
    [value]: value
  }), {
    ' ': undefined
  });
}