"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.addWebpackConfig = addWebpackConfig;

var path = _interopRequireWildcard(require("path"));

function _getRequireWildcardCache() { if (typeof WeakMap !== "function") return null; var cache = new WeakMap(); _getRequireWildcardCache = function () { return cache; }; return cache; }

function _interopRequireWildcard(obj) { if (obj && obj.__esModule) { return obj; } if (obj === null || typeof obj !== "object" && typeof obj !== "function") { return { default: obj }; } var cache = _getRequireWildcardCache(); if (cache && cache.has(obj)) { return cache.get(obj); } var newObj = {}; var hasPropertyDescriptor = Object.defineProperty && Object.getOwnPropertyDescriptor; for (var key in obj) { if (Object.prototype.hasOwnProperty.call(obj, key)) { var desc = hasPropertyDescriptor ? Object.getOwnPropertyDescriptor(obj, key) : null; if (desc && (desc.get || desc.set)) { Object.defineProperty(newObj, key, desc); } else { newObj[key] = obj[key]; } } } newObj.default = obj; if (cache) { cache.set(obj, newObj); } return newObj; }

/* eslint @typescript-eslint/no-var-requires: off */
const SVG_ICONS_PATH_REGEX = /icons\/.*\.svg$/;
const IMAGE_PATH_REGEX = /\.(jpe?g|png|gif|svg)$/;
const LIBRARY_REGEX = /node_modules\/@shopify\/checkout-ui-react/;

function addWebpackConfig(config, {
  preact = true,
  development = process.env.NODE_ENV === 'development'
} = {}) {
  var _config$resolve$exten, _config$resolve, _ref, _config$resolve2, _config$resolve3, _config$module$rules, _config$module;

  const MiniCssExtractPlugin = require('mini-css-extract-plugin');

  const postcssPresetEnv = require('postcss-preset-env');

  const postcssFunctions = require('postcss-functions');

  const postcssLogical = require('postcss-logical');

  const postcssDirPseudoClass = require('postcss-dir-pseudo-class');

  return { ...config,
    resolve: { ...config.resolve,
      // Adds .esnext extensions, which this library uses for optimized build
      // outputs
      extensions: ['.esnext', ...((_config$resolve$exten = (_config$resolve = config.resolve) === null || _config$resolve === void 0 ? void 0 : _config$resolve.extensions) !== null && _config$resolve$exten !== void 0 ? _config$resolve$exten : ['.mjs', '.js', '.json'])],
      mainFields: ['esnext', ...((_ref = (_config$resolve2 = config.resolve) === null || _config$resolve2 === void 0 ? void 0 : _config$resolve2.mainFields) !== null && _ref !== void 0 ? _ref : ['browser', 'module', 'main'])],
      alias: { ...((_config$resolve3 = config.resolve) === null || _config$resolve3 === void 0 ? void 0 : _config$resolve3.alias),
        ...(preact ? {
          react: 'preact/compat',
          'react-dom': 'preact/compat'
        } : {})
      }
    },
    module: { ...config.module,
      rules: [...((_config$module$rules = (_config$module = config.module) === null || _config$module === void 0 ? void 0 : _config$module.rules) !== null && _config$module$rules !== void 0 ? _config$module$rules : []), {
        test: /\.esnext$/,
        include: LIBRARY_REGEX,
        use: {
          loader: 'babel-loader',
          options: {
            configFile: false,
            sourceType: 'unambiguous',
            presets: [['@babel/preset-env', {
              modules: false,
              corejs: 3,
              useBuiltIns: 'usage'
            }]]
          }
        }
      }, {
        test: /\.css$/,
        include: LIBRARY_REGEX,
        use: [development ? {
          loader: 'style-loader'
        } : {
          loader: MiniCssExtractPlugin.loader,
          options: {
            esModule: true
          }
        }, {
          loader: 'css-loader',
          options: {
            esModule: true,
            modules: {
              localIdentName: development ? '[name]-[local]_[hash:base64:5]' : '[hash:base64:5]'
            },
            importLoaders: 1,
            sourceMap: !development,
            onlyLocals: false
          }
        }, {
          loader: 'postcss-loader',
          options: {
            ident: 'postcss-checkout-ui',
            plugins: () => [// @see https://github.com/csstools/postcss-preset-env
            postcssPresetEnv({
              stage: 3,
              autoprefixer: {
                grid: true
              },
              importFrom: [path.join(path.dirname(require.resolve('@shopify/checkout-ui-react')), 'src/style.css')],
              preserve: true,
              // @see https://preset-env.cssdb.org/features
              // @see https://github.com/csstools/postcss-preset-env/blob/master/src/lib/plugins-by-id.js#L36
              features: {
                'nesting-rules': true,
                'dir-pseudo-class': false,
                'logical-properties-and-values': false
              }
            }), // PostCSS Preset Env uses caniuse to determine whether the plugins should run or not
            // There are currently false positives that cause PostCSS Logical not to run, so we run it independently for now
            // @see https://github.com/csstools/postcss-preset-env/issues/138
            postcssLogical({
              preserve: true
            }), postcssDirPseudoClass({
              preserve: true
            }), postcssFunctions({
              functions: {
                rem(target, root = '10px') {
                  if (target.includes('px')) {
                    return `${parseFloat(target) / parseFloat(root)}rem`;
                  } else {
                    throw new Error('Value must be in pixels.');
                  }
                },

                em(target, parent = '14px') {
                  if (target.includes('px')) {
                    return `${parseFloat(target) / parseFloat(parent)}em`;
                  } else {
                    throw new Error('Value must be in pixels.');
                  }
                }

              }
            })]
          }
        }]
      }, {
        include: LIBRARY_REGEX,

        test(resource) {
          return SVG_ICONS_PATH_REGEX.test(resource);
        },

        use: ['@svgr/webpack']
      }, {
        include: LIBRARY_REGEX,

        test(resource) {
          return IMAGE_PATH_REGEX.test(resource) && !SVG_ICONS_PATH_REGEX.test(resource);
        },

        use: [{
          loader: 'file-loader',
          options: {
            emitFile: true
          }
        }, !development && {
          loader: 'image-webpack-loader'
        }].filter(Boolean)
      }]
    }
  };
}