"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.useEffectRect = exports.useRect = exports.usePopper = void 0;
const react_1 = require("react");
const context_1 = require("./context");
function usePopper() {
    const context = react_1.useContext(context_1.PopperContext);
    if (context === null) {
        throw new Error('No Popper in context');
    }
    return context;
}
exports.usePopper = usePopper;
function useRect() {
    const [rect, setRect] = react_1.useState(null);
    const ref = react_1.useCallback((node) => {
        if (node !== null) {
            setRect(node.getBoundingClientRect());
        }
    }, []);
    return [rect, ref];
}
exports.useRect = useRect;
function useEffectRect(ref) {
    const [rect, setRect] = react_1.useState(null);
    const setBoundingRect = react_1.useCallback(() => {
        if (ref !== null) {
            setRect(ref.getBoundingClientRect());
        }
    }, [ref]);
    react_1.useLayoutEffect(() => {
        setBoundingRect();
        window.addEventListener('resize', setBoundingRect);
        window.addEventListener('scroll', setBoundingRect);
        return () => {
            window.removeEventListener('resize', setBoundingRect);
            window.removeEventListener('scroll', setBoundingRect);
        };
    }, [setBoundingRect]);
    return rect;
}
exports.useEffectRect = useEffectRect;
