"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.primaryAndSecondaryActions = exports.primaryAction = exports.withGroupedSectionsAndShowcase = exports.withGroupedSections = exports.withSectionsAndShowcase = exports.withSections = exports.noActions = void 0;
const react_1 = __importDefault(require("react"));
const addon_knobs_1 = require("@storybook/addon-knobs");
const Button_1 = require("../Button");
const storybook_utilities_1 = require("../../storybook-utilities");
const Step_1 = require("./Step");
const meta = {
    component: Step_1.Step,
    title: 'Step',
    decorators: [addon_knobs_1.withKnobs, storybook_utilities_1.themeWithKnobs('actions')],
};
exports.default = meta;
const stepContent = <p>Content</p>;
const stepSectionContent = <p>Section content</p>;
const stepSectionShowcase = <p>Showcased content</p>;
exports.noActions = () => (<Step_1.Step>
    <Step_1.StepContent>
      <p>Content</p>
    </Step_1.StepContent>
  </Step_1.Step>);
exports.withSections = () => (<Step_1.Step>
    <Step_1.StepContent>
      <Step_1.StepSection title="Contact information" description="This is a description">
        {stepSectionContent}
      </Step_1.StepSection>
      <Step_1.StepSection title="Shipping information" description="This is a description">
        {stepSectionContent}
      </Step_1.StepSection>
      <Step_1.StepSection>
        <p>This is Section content without a Title</p>
      </Step_1.StepSection>
    </Step_1.StepContent>
  </Step_1.Step>);
exports.withSectionsAndShowcase = () => (<Step_1.Step>
    <Step_1.StepContent>
      <Step_1.StepSection>
        <Step_1.StepSectionShowcase>{stepSectionShowcase}</Step_1.StepSectionShowcase>
        <Step_1.StepSectionHeader title="Contact information" description="This is a description"/>
        <Step_1.StepSectionShowcase>{stepSectionShowcase}</Step_1.StepSectionShowcase>
        {stepSectionContent}
        <Step_1.StepSectionShowcase>{stepSectionShowcase}</Step_1.StepSectionShowcase>
      </Step_1.StepSection>
    </Step_1.StepContent>
  </Step_1.Step>);
exports.withGroupedSections = () => (<Step_1.Step>
    <Step_1.StepContent grouped>
      <Step_1.StepSection title="Contact information" description="This is a description">
        {stepSectionContent}
      </Step_1.StepSection>
      <Step_1.StepSection title="Shipping information" description="This is a description">
        {stepSectionContent}
      </Step_1.StepSection>
      <Step_1.StepSection>
        <p>This is Section content without a Title</p>
      </Step_1.StepSection>
    </Step_1.StepContent>
  </Step_1.Step>);
exports.withGroupedSectionsAndShowcase = () => (<Step_1.Step>
    <Step_1.StepContent grouped>
      <Step_1.StepSection>
        <Step_1.StepSectionShowcase>{stepSectionShowcase}</Step_1.StepSectionShowcase>
        <Step_1.StepSectionHeader title="Contact information" description="This is a description"/>
        {stepSectionContent}
        <Step_1.StepSectionShowcase>{stepSectionShowcase}</Step_1.StepSectionShowcase>
        <Step_1.StepSectionShowcase>{stepSectionShowcase}</Step_1.StepSectionShowcase>
      </Step_1.StepSection>
    </Step_1.StepContent>
  </Step_1.Step>);
exports.primaryAction = () => (<Step_1.Step>
    <Step_1.StepContent>{stepSectionContent}</Step_1.StepContent>
    <Step_1.StepActions>
      <Step_1.StepPrimaryAction>
        <Button_1.Button fill to="/shipping">
          Continue to shipping
        </Button_1.Button>
      </Step_1.StepPrimaryAction>
    </Step_1.StepActions>
  </Step_1.Step>);
exports.primaryAndSecondaryActions = () => (<Step_1.Step>
    <Step_1.StepContent>{stepContent}</Step_1.StepContent>
    <Step_1.StepActions>
      <Step_1.StepPrimaryAction>
        <Button_1.Button fill to="/shipping">
          Continue to shipping
        </Button_1.Button>
      </Step_1.StepPrimaryAction>
      <Step_1.StepSecondaryAction>
        <Button_1.Button to="/cart" plain fill>
          Return to cart
        </Button_1.Button>
      </Step_1.StepSecondaryAction>
    </Step_1.StepActions>
  </Step_1.Step>);
