"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const react_1 = __importDefault(require("react"));
const dom_1 = require("@quilted/react-testing/dom");
const TextBlock_1 = require("../../../TextBlock");
const Stepper_1 = require("../../Stepper");
const VisuallyHidden_1 = require("../../../VisuallyHidden");
const StepperStep_1 = require("./StepperStep");
const defaultProps = (id) => ({
    id: `step${id}`,
    icon: 'checkmark',
    label: `Step ${id}`,
    state: `State ${id}`,
});
describe('<StepperStep />', () => {
    it('renders a <StepperStepConnector /> except for first StepperStep', () => {
        const stepper = dom_1.mount(<Stepper_1.Stepper activeStep="step3">
        <StepperStep_1.StepperStep {...defaultProps(1)}/>
        <StepperStep_1.StepperStep {...defaultProps(2)}/>
        <StepperStep_1.StepperStep {...defaultProps(3)}/>
      </Stepper_1.Stepper>);
        const [firstStepperStep, secondStepperStep, finalStepperStep,] = stepper.findAll(StepperStep_1.StepperStep);
        expect(firstStepperStep).not.toContainReactComponent(StepperStep_1.StepperStepConnector);
        expect(secondStepperStep).toContainReactComponent(StepperStep_1.StepperStepConnector, {
            active: false,
            completed: true,
        });
        expect(finalStepperStep).toContainReactComponent(StepperStep_1.StepperStepConnector, {
            active: true,
            completed: false,
        });
    });
    it('renders <StepperStepIcon />', () => {
        const stepper = dom_1.mount(<Stepper_1.Stepper activeStep="step2">
        <StepperStep_1.StepperStep {...defaultProps(1)}/>
        <StepperStep_1.StepperStep {...defaultProps(2)}/>
        <StepperStep_1.StepperStep {...defaultProps(3)} iconColor="critical"/>
      </Stepper_1.Stepper>);
        const [firstStepperStep, secondStepperStep, finalStepperStep,] = stepper.findAll(StepperStep_1.StepperStep);
        expect(firstStepperStep).toContainReactComponent(StepperStep_1.StepperStepIcon, {
            active: false,
            completed: true,
            source: 'checkmark',
        });
        expect(secondStepperStep).toContainReactComponent(StepperStep_1.StepperStepIcon, {
            active: true,
            completed: false,
            source: 'checkmark',
        });
        expect(finalStepperStep).toContainReactComponent(StepperStep_1.StepperStepIcon, {
            active: false,
            completed: false,
            source: 'checkmark',
            color: 'critical',
        });
    });
    it('renders <StepperStepLabel /> with state', () => {
        const stepper = dom_1.mount(<Stepper_1.Stepper>
        <StepperStep_1.StepperStep {...defaultProps(1)}/>
        <StepperStep_1.StepperStep {...defaultProps(2)} stateHidden={false}/>
      </Stepper_1.Stepper>);
        const [firstStepperStep, finalStepperStep] = stepper.findAll(StepperStep_1.StepperStep);
        expect(firstStepperStep).toContainReactComponent(StepperStep_1.StepperStepLabel, {
            state: 'State 1',
        });
        expect(finalStepperStep).toContainReactComponent(StepperStep_1.StepperStepLabel, {
            state: 'State 2',
        });
        expect(firstStepperStep).toContainReactComponent(VisuallyHidden_1.VisuallyHidden);
        expect(firstStepperStep).toContainReactComponentTimes(TextBlock_1.TextBlock, 1);
        expect(finalStepperStep).not.toContainReactComponent(VisuallyHidden_1.VisuallyHidden);
        expect(finalStepperStep).toContainReactComponentTimes(TextBlock_1.TextBlock, 2);
        expect(firstStepperStep.find(VisuallyHidden_1.VisuallyHidden)).toContainReactText('State 1');
        expect(finalStepperStep.find(TextBlock_1.TextBlock)).toContainReactText('State 2');
    });
    it('renders <StepperStepLabel /> with label or description', () => {
        const stepper = dom_1.mount(<Stepper_1.Stepper activeStep="step2">
        <StepperStep_1.StepperStep {...defaultProps(1)} description="Description 1"/>
        <StepperStep_1.StepperStep {...defaultProps(2)} description="Description 2"/>
        <StepperStep_1.StepperStep {...defaultProps(3)}/>
      </Stepper_1.Stepper>);
        const [firstStepperStep, secondStepperStep, finalStepperStep,] = stepper.findAll(StepperStep_1.StepperStep);
        expect(firstStepperStep).toContainReactComponent(StepperStep_1.StepperStepLabel, {
            label: 'Step 1',
            description: 'Description 1',
        });
        expect(secondStepperStep).toContainReactComponent(StepperStep_1.StepperStepLabel, {
            label: 'Step 2',
            description: 'Description 2',
        });
        expect(finalStepperStep).toContainReactComponent(StepperStep_1.StepperStepLabel, {
            label: 'Step 3',
        });
        expect(firstStepperStep.find(TextBlock_1.TextBlock)).toContainReactText('Step 1');
        expect(secondStepperStep.find(TextBlock_1.TextBlock)).toContainReactText('Step 2');
        expect(finalStepperStep.find(TextBlock_1.TextBlock)).toContainReactText('Step 3');
        expect(firstStepperStep).toContainReactComponentTimes(TextBlock_1.TextBlock, 2);
        expect(secondStepperStep).toContainReactComponentTimes(TextBlock_1.TextBlock, 2);
        expect(finalStepperStep).toContainReactComponentTimes(TextBlock_1.TextBlock, 1);
    });
    it('renders a <li> with a aria-current attribute', () => {
        const stepper = dom_1.mount(<Stepper_1.Stepper activeStep="step2">
        <StepperStep_1.StepperStep {...defaultProps(1)}/>
        <StepperStep_1.StepperStep {...defaultProps(2)}/>
        <StepperStep_1.StepperStep {...defaultProps(3)}/>
      </Stepper_1.Stepper>);
        const [firstStepperStep, secondStepperStep, finalStepperStep,] = stepper.findAll(StepperStep_1.StepperStep);
        expect(firstStepperStep).toContainReactComponent('li', {
            'aria-current': false,
        });
        expect(secondStepperStep).toContainReactComponent('li', {
            'aria-current': true,
        });
        expect(finalStepperStep).toContainReactComponent('li', {
            'aria-current': false,
        });
    });
});
