"use strict";
var __createBinding = (this && this.__createBinding) || (Object.create ? (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    Object.defineProperty(o, k2, { enumerable: true, get: function() { return m[k]; } });
}) : (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    o[k2] = m[k];
}));
var __setModuleDefault = (this && this.__setModuleDefault) || (Object.create ? (function(o, v) {
    Object.defineProperty(o, "default", { enumerable: true, value: v });
}) : function(o, v) {
    o["default"] = v;
});
var __importStar = (this && this.__importStar) || function (mod) {
    if (mod && mod.__esModule) return mod;
    var result = {};
    if (mod != null) for (var k in mod) if (k !== "default" && Object.hasOwnProperty.call(mod, k)) __createBinding(result, mod, k);
    __setModuleDefault(result, mod);
    return result;
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.Arrow = exports.Tooltip = exports.SPACE_KEY_CODE = exports.ESCAPE_KEY_CODE = exports.RETURN_KEY_CODE = void 0;
const react_1 = __importStar(require("react"));
const css_utilities_1 = require("@shopify/css-utilities");
const id_1 = require("../../utilities/id");
const transition_1 = require("../../utilities/transition");
const Popper_1 = require("../Popper");
const Tooltip_css_1 = __importDefault(require("./Tooltip.css"));
exports.RETURN_KEY_CODE = 13;
exports.ESCAPE_KEY_CODE = 27;
exports.SPACE_KEY_CODE = 32;
const createId = id_1.createIdCreator('Tooltip');
function Tooltip({ content, children }) {
    const [active, setActive] = react_1.useState(false);
    const buttonRef = react_1.useRef(null);
    const transition = transition_1.useTransition(active, {
        exit: 'slow',
    });
    function handleKeyDown(event) {
        switch (event.keyCode) {
            case exports.RETURN_KEY_CODE:
            case exports.SPACE_KEY_CODE:
                event.preventDefault();
                setActive(!active);
                break;
            case exports.ESCAPE_KEY_CODE:
                event.preventDefault();
                setActive(false);
                break;
        }
    }
    function handleClick() {
        setActive(!active);
    }
    const className = css_utilities_1.classNames(Tooltip_css_1.default.Tooltip, Tooltip_css_1.default[css_utilities_1.variationName('transition', transition)]);
    const id = id_1.useId(undefined, createId);
    const controlId = active ? id : undefined;
    return (<div className={Tooltip_css_1.default.Wrapper}>
      <button type="button" className={Tooltip_css_1.default.Button} aria-pressed={active} aria-controls={controlId} aria-describedby={controlId} onFocus={() => {
        setActive(true);
    }} onBlur={() => {
        setActive(false);
    }} onMouseEnter={() => {
        setActive(true);
    }} onMouseLeave={() => {
        setActive(false);
    }} onClick={handleClick} onKeyDown={handleKeyDown} ref={buttonRef}>
        {children}
      </button>
      {transition !== 'exited' && (<Popper_1.Popper activator={buttonRef.current} preventOverflow>
          
          <p id={controlId} role="tooltip" onMouseEnter={() => {
        setActive(true);
    }} onMouseLeave={() => {
        setActive(false);
    }} className={className}>
            {content}
            <Arrow />
          </p>
        </Popper_1.Popper>)}
    </div>);
}
exports.Tooltip = Tooltip;
function Arrow() {
    const { clipping } = Popper_1.usePopper();
    const offsetX = (clipping.right || clipping.left) &&
        `calc(${document.dir === 'ltr' ? '-50' : '50'}% - ${clipping.right || clipping.left}px)`;
    return (<div className={Tooltip_css_1.default.Arrow} style={Object.assign({}, (offsetX && {
        transform: `translateX(${offsetX})`,
        MozTransform: `translateX(${offsetX})`,
        webkitTransform: `translateX(${offsetX})`,
    }))}/>);
}
exports.Arrow = Arrow;
