"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.useTransition = exports.durations = void 0;
const react_1 = require("react");
const media_query_1 = require("./media-query");
exports.durations = new Map([
    ['none', 0],
    ['fast', 100],
    ['base', 200],
    ['slow', 300],
    ['slower', 400],
    ['slowest', 500],
]);
function useTransition(transitionIn, duration = 'slow') {
    const [state, setState] = react_1.useState(transitionIn);
    const [transitioning, setTransitioning] = react_1.useState(false);
    const transitionInRef = react_1.useRef(transitionIn);
    const endTransitionRef = react_1.useRef(() => {
        setTransitioning(false);
        setState(transitionInRef.current);
    });
    const prefersReducedMotion = media_query_1.usePrefersReducedMotion();
    react_1.useEffect(() => {
        if (transitionIn !== transitionInRef.current)
            setTransitioning(true);
        transitionInRef.current = transitionIn;
        let enterDuration = typeof duration === 'string' ? duration : duration.enter;
        let exitDuration = typeof duration === 'string' ? duration : duration.exit;
        if (prefersReducedMotion) {
            enterDuration = 'none';
            exitDuration = 'none';
        }
        const timeout = setTimeout(endTransitionRef.current, transitionIn
            ? exports.durations.get(enterDuration !== null && enterDuration !== void 0 ? enterDuration : 'none')
            : exports.durations.get(exitDuration !== null && exitDuration !== void 0 ? exitDuration : 'none'));
        return () => {
            clearTimeout(timeout);
        };
    }, [duration, prefersReducedMotion, transitionIn]);
    if (transitioning) {
        return transitionIn ? 'entering' : 'exiting';
    }
    if (transitionIn === state) {
        return transitionIn ? 'entered' : 'exited';
    }
    return transitionIn ? 'enter' : 'exit';
}
exports.useTransition = useTransition;
